summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmobjectlinkedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmobjectlinkedit.h')
-rw-r--r--kpovmodeler/pmobjectlinkedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmobjectlinkedit.h b/kpovmodeler/pmobjectlinkedit.h
index 82ed645d..58313c26 100644
--- a/kpovmodeler/pmobjectlinkedit.h
+++ b/kpovmodeler/pmobjectlinkedit.h
@@ -39,9 +39,9 @@ class PMObjectLinkEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMObjectLinkEdit with tqparent and name
*/
- PMObjectLinkEdit( TQWidget* tqparent, const char* name = 0 );
+ PMObjectLinkEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMObjectLinkEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMObjectLinkEdit with tqparent and name
+ * Creates a PMObjectLinkEdit with parent and name
*/